@@ -1,10 +1,8 @@
 use strict;
 use warnings;
 package DAIA::Availability;
-{
-  $DAIA::Availability::VERSION = '0.421';
-}
 #ABSTRACT: Abstract base class of availability information
+our $VERSION = '0.43'; #VERSION
 
 use base 'DAIA::Object';
 
@@ -261,15 +259,18 @@ sub date_or_datetime {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 DAIA::Availability - Abstract base class of availability information
 
 =head1 VERSION
 
-version 0.421
+version 0.43
 
 =head1 DESCRIPTION
 
@@ -396,14 +397,13 @@ Datatypes specification. Fractions of seconds are ignored.
 
 =head1 AUTHOR
 
-Jakob Voss
+Jakob Voß
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Jakob Voss.
+This software is copyright (c) 2013 by Jakob Voß.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
