@@ -1,10 +1,8 @@
 use strict;
 use warnings;
 package DAIA::Message;
-{
-  $DAIA::Message::VERSION = '0.421';
-}
 #ABSTRACT: An optional information or error message
+our $VERSION = '0.43'; #VERSION
 
 use base 'DAIA::Object';
 
@@ -64,17 +62,19 @@ sub is_language_tag {
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 DAIA::Message - An optional information or error message
 
 =head1 VERSION
 
-version 0.421
+version 0.43
 
 =head1 DESCRIPTION
 
@@ -138,14 +138,13 @@ support have a look at L<I18N::LangTags>.
 
 =head1 AUTHOR
 
-Jakob Voss
+Jakob Voß
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Jakob Voss.
+This software is copyright (c) 2013 by Jakob Voß.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
