@@ -1,10 +1,8 @@
 use strict;
 use warnings;
 package DAIA::Response;
-{
-  $DAIA::Response::VERSION = '0.421';
-}
 #ABSTRACT: DAIA information root element
+our $VERSION = '0.43'; #VERSION
 
 use base 'DAIA::Object';
 
@@ -126,17 +124,19 @@ sub check_valid_id {
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 DAIA::Response - DAIA information root element
 
 =head1 VERSION
 
-version 0.421
+version 0.43
 
 =head1 SYNOPSIS
 
@@ -211,14 +211,13 @@ appends an error message ("please provide a document id" or "document id
 
 =head1 AUTHOR
 
-Jakob Voss
+Jakob Voß
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Jakob Voss.
+This software is copyright (c) 2013 by Jakob Voß.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
